@@ -1,6 +1,5 @@
 """Module to organize fluids."""
 from warnings import warn
-
 import CoolProp.CoolProp as CP
 
 
@@ -18,36 +17,37 @@ fluid_list = {name: Fluid(name) for name in _fluid_list}
 
 # define possible names
 fluid_list["IsoButane"].possible_names.extend(
-    ["isobutane", "i-butane", "ibutane", "isobutan", "I-BUTANE"]
+    ["isobutane", "i-butane", "ibutane", "isobutan", "iso-butane"]
 )
 fluid_list["n-Butane"].possible_names.extend(["butane", "n-butane", "nbutane"])
+fluid_list["trans-2-Butene"].possible_names.extend(["trans-butene", "trans-butene-2"])
+fluid_list["IsoButene"].possible_names.extend(["i-butene", "ibutene", "iso-butene"])
+fluid_list["cis-2-Butene"].possible_names.extend(["cis-butene", "cis-butene-2"])
 fluid_list["n-Pentane"].possible_names.extend(["pentane", "n-pentane", "npentane"])
 fluid_list["Isopentane"].possible_names.extend(
-    ["isopentane", "i-pentane", "ipentane", "I-PENTANE"]
+    ["i-pentane", "ipentane", "iso-pentane", "isopentane"]
 )
 fluid_list["n-Hexane"].possible_names.extend(["hexane", "n-hexane", "nhexane"])
-fluid_list["Isohexane"].possible_names.extend(["isohexane", "i-hexane"])
+fluid_list["Isohexane"].possible_names.extend(["isohexane", "i-hexane", "iso-hexane"])
 fluid_list["n-Heptane"].possible_names.extend(["heptane", "n-heptane"])
 fluid_list["n-Octane"].possible_names.extend(["octane", "n-octane"])
 fluid_list["n-Undecane"].possible_names.extend(["undecane", "n-undecane"])
 fluid_list["n-Dodecane"].possible_names.extend(["dodecane", "n-dodecane"])
-fluid_list["HydrogenSulfide"].possible_names.extend(
-    ["hydrogen sulfide", "HYDROGEN SULFIDE", "h2s"]
-)
-fluid_list["CarbonMonoxide"].possible_names.extend(
-    ["carbon monoxide", "CARBON MONOXIDE", "co"]
-)
-fluid_list["CarbonDioxide"].possible_names.extend(["carbon dioxide", "CARBON DIOXIDE"])
-fluid_list["Nitrogen"].possible_names.extend(["N2", "n2"])
-fluid_list["Oxygen"].possible_names.extend(["O2", "o2"])
-fluid_list["Hydrogen"].possible_names.extend(["H2", "h2"])
+fluid_list["HydrogenSulfide"].possible_names.extend(["hydrogen sulfide", "h2s"])
+fluid_list["CarbonMonoxide"].possible_names.extend(["carbon monoxide", "co"])
+fluid_list["CarbonDioxide"].possible_names.extend(["carbon dioxide"])
+fluid_list["Nitrogen"].possible_names.extend(["n2"])
+fluid_list["Oxygen"].possible_names.extend(["o2"])
+fluid_list["Hydrogen"].possible_names.extend(["h2"])
+fluid_list["Propylene"].possible_names.extend(["propene"])
+fluid_list["Ethylene"].possible_names.extend(["ethene"])
 
 
 def get_name(name):
     """Seach for compatible fluid name."""
 
     for k, v in fluid_list.items():
-        if name in v.possible_names:
+        if name.lower() in v.possible_names:
             name = k
 
     fluid_name = CP.get_REFPROPname(name)
@@ -77,19 +77,29 @@ def normalize_mix(molar_fractions):
     molar_fractions: list
         Molar fractions list will be modified in place.
     """
-    total = sum(molar_fractions)
+    total = sum(sorted(list(molar_fractions)))
+
     if not ((0.95 < total < 1.05) or (95 < total < 105)):
         warn(f"Molar fraction far from 1 or 100% -> Total: {total}")
 
-    for i, comp in enumerate(molar_fractions):
-        molar_fractions[i] = comp / total
+    molar_fractions_dict = {k: v for k, v in enumerate(molar_fractions)}
+    molar_fractions_dict = dict(
+        sorted(molar_fractions_dict.items(), key=lambda item: -item[1])
+    )
 
-    try:
-        # try to sum to exactly 1.
-        molar_fractions_back = molar_fractions.copy()
-        while sum(molar_fractions) != 1.0:
-            diff = sum(molar_fractions) - 1.0
-            molar_fractions[i] = molar_fractions[i] - diff
-            i += 1
-    except IndexError:
-        molar_fractions = molar_fractions_back
+    # skip component with highest fraction
+    molar_fractions_dict_iter = iter(molar_fractions_dict.items())
+    next(molar_fractions_dict_iter)
+
+    normalized_total = 0
+    for k, v in molar_fractions_dict_iter:
+        if v != 0:
+            new_fraction = 1.0 - (1.0 - v / total)
+            molar_fractions_dict[k] = new_fraction
+            normalized_total += new_fraction
+
+    # adjust component with highest fraction so that sum == 1.0
+    molar_fractions_dict[next(iter(molar_fractions_dict))] = 1.0 - normalized_total
+
+    for k, v in molar_fractions_dict.items():
+        molar_fractions[k] = molar_fractions_dict[k]
