@@ -434,16 +434,28 @@ class Impeller:
         head_curves=None,
         eff_curves=None,
         power_curves=None,
+        pressure_ratio_curves=None,
+        disch_T_curves=None,
         b=None,
         D=None,
         number_of_points=10,
         flow_units="m**3/s",
+        flow_units_head=None,
+        flow_units_eff=None,
+        flow_units_power=None,
+        flow_units_pressure_ratio=None,
+        flow_units_disch_T=None,
         head_units="J/kg",
+        eff_units="dimensionless",
+        pressure_ratio_units="dimensionless",
+        disch_T_units="degK",
         power_units="W",
         speed_units="RPM",
         head_interpolation_method="interp1d",
         eff_interpolation_method="interp1d",
         power_interpolation_method="interp1d",
+        pressure_ratio_interpolation_method="interp1d",
+        disch_T_interpolation_method="interp1d",
     ):
         """Create points from dict object.
 
@@ -459,10 +471,12 @@ class Impeller:
 
         suc : ccp.State
             Suction state.
-        head_curve : dict
-            Dict with head/flow values.
-        eff_curve : dict
+        head_curves : dict
             Dict with head/flow values.
+        eff_curves : dict
+            Dict with eff/flow values.
+        power_curves : dict
+            Dict with power/flow values.
         b : float, pint.Quantity
             Impeller width (m).
         D : float, pint.Quantity
@@ -471,9 +485,32 @@ class Impeller:
             Number of points that will be interpolated.
         flow_units : str
             Flow units used in the dict.
+        flow_units_head: str
+            Flow units used in the dict for head curves.
+            Only needed when flow units for head curve differs from other curves.
+        flow_units_eff: str
+            Flow units used  in the dict for efficiency curves.
+            Only needed when flow units for efficiency curve differs from other curves.
+        flow_units_power: str
+            Flow units used  in the dict for power curves.
+            Only needed when flow units for power curve differs from other curves.
+        flow_units_pressure_ratio: str
+            Flow units used  in the dict for pressure ratio curves.
+            Only needed when flow units for efficiency curve differs from other curves.
+        flow_units_disch_T: str
+            Flow units used  in the dict for discharge Temperature curves.
+            Only needed when flow units for efficiency curve differs from other curves.
         head_units : str
             Head units used in the dict.
             If the curve head units are in meter you can use: head_units="m*g0".
+        eff_units : str
+            Dimensionless.
+        power_units : str
+            Power units used in the dict.
+        pressure_ratio_units : str
+            Pressure ratio units used in the dict.
+        disch_T_units : str
+            Discharge temperature units used in the dict.
         speed_units : str
             Speed units used in the dict.
         head_interpolation_method : str, optional
@@ -487,140 +524,146 @@ class Impeller:
             Default is interp1d.
         """
         # define if we have volume or mass flow
+        args = locals().copy()
+
         flow_type = "volumetric"
         if list(Q_(1, flow_units).dimensionality.keys())[0] == "[mass]":
             flow_type = "mass"
 
         points = []
 
-        for speed, head_curve in head_curves.items():
-            head_interpolated = interp1d(
-                head_curve["x"],
-                head_curve["y"],
-                kind=3,
-                fill_value="extrapolate",
+        curves = {}
+        for k, v in args.items():
+            if "curves" in k and v is not None:
+                name_split = k.split("_")
+                try:
+                    curve_name = "_".join(name_split[:-1])
+                except TypeError:
+                    curve_name = name_split[0]
+                curves[curve_name] = v
+
+        parameters = list(curves)
+        interpolation_methods = [
+            args[f"{param}_interpolation_method"] for param in parameters
+        ]
+        speeds = list(curves[parameters[0]])
+
+        for param in parameters:
+            if not args[f"flow_units_{param}"]:
+                args[f"flow_units_{param}"] = flow_units
+
+        flow_units_list = {
+            f"flow_units_{param}": (
+                "mass"
+                if list(Q_(1, args[f"flow_units_{param}"]).dimensionality.keys())[0]
+                == "[mass]"
+                else "volumetric"
             )
-            head_spline = UnivariateSpline(
-                head_curve["x"],
-                head_curve["y"],
-            )
-            if eff_curves:
-                eff_curve = eff_curves[speed]
-                # check eff scale
-                if max(eff_curve["y"]) > 1:
-                    eff_curve["y"] = [i / 100 for i in eff_curve["y"]]
-                eff_interpolated = interp1d(
-                    eff_curve["x"],
-                    eff_curve["y"],
+            for param in parameters
+        }
+
+        if "eff" in curves:
+            if max(curves["eff"][speeds[0]]["y"]) > 1:
+                for speed in speeds:
+                    curves["eff"][speed]["y"] = [
+                        i / 100 for i in curves["eff"][speed]["y"]
+                    ]
+
+        # create interpolated curves
+        curves_interpolated = {"interp1d": {}, "UnivariateSpline": {}}
+        # dict to hold interpolated values for specific x values
+        points_interpolated = {"interp1d": {}, "UnivariateSpline": {}}
+
+        for speed in speeds:
+            min_x = 0
+            max_x = 1e20
+            # get min and max flow
+            for curve in curves:
+                if flow_units_list[f"flow_units_{curve}"] != flow_type:
+                    if flow_units_list[f"flow_units_{curve}"] == "mass":
+                        flow_curve = [
+                            Q_(flow, args[f"flow_units_{curve}"]) / suc.rho()
+                            for flow in curves[curve][speed]["x"]
+                        ]
+                        curves[curve][speed]["x"] = [
+                            flow.to(flow_units).m for flow in flow_curve
+                        ]
+                    else:
+                        flow_curve = [
+                            Q_(flow, args[f"flow_units_{curve}"]) * suc.rho()
+                            for flow in curves[curve][speed]["x"]
+                        ]
+                        curves[curve][speed]["x"] = [
+                            flow.to(flow_units).m for flow in flow_curve
+                        ]
+                if curves[curve][speed]["x"][0] > min_x:
+                    min_x = curves[curve][speed]["x"][0]
+                if curves[curve][speed]["x"][-1] < max_x:
+                    max_x = curves[curve][speed]["x"][-1]
+
+            points_x = np.linspace(min_x, max_x, number_of_points)
+
+            for curve in curves:
+                curves_interpolated["interp1d"][curve] = {}
+                points_interpolated["interp1d"][curve] = {}
+
+                curves_interpolated["interp1d"][curve][speed] = interp1d(
+                    curves[curve][speed]["x"],
+                    curves[curve][speed]["y"],
                     kind=3,
                     fill_value="extrapolate",
                 )
-                eff_spline = UnivariateSpline(
-                    eff_curve["x"],
-                    eff_curve["y"],
-                )
-            if power_curves:
-                power_curve = power_curves[speed]
-                power_interpolated = interp1d(
-                    power_curve["x"],
-                    power_curve["y"],
-                    kind=3,
-                    fill_value="extrapolate",
-                )
-                power_spline = UnivariateSpline(
-                    power_curve["x"],
-                    power_curve["y"],
-                )
+                points_interpolated["interp1d"][curve][speed] = curves_interpolated[
+                    "interp1d"
+                ][curve][speed](points_x)
 
-            # check for possible interpolation error by comparing interp1d and spline
-            # avoid too much extrapolation
-            if eff_curves:
-                min_x = max(head_curve["x"][0], eff_curve["x"][0])
-                max_x = min(head_curve["x"][-1], eff_curve["x"][-1])
-                points_x = np.linspace(min_x, max_x, number_of_points)
-            if power_curves:
-                min_x = max(head_curve["x"][0], power_curve["x"][0])
-                max_x = min(head_curve["x"][-1], power_curve["x"][-1])
-                points_x = np.linspace(min_x, max_x, number_of_points)
-
-            head_max_error = max(
-                1 - (head_interpolated(points_x) / head_spline(points_x))
-            )
-
-            if eff_curves:
-                eff_max_error = max(
-                    1 - (eff_interpolated(points_x) / eff_spline(points_x))
-                )
-            if power_curves:
-                power_max_error = max(
-                    1 - (power_interpolated(points_x) / power_spline(points_x))
+                curves_interpolated["UnivariateSpline"][curve] = {}
+                points_interpolated["UnivariateSpline"][curve] = {}
+                curves_interpolated["UnivariateSpline"][curve][
+                    speed
+                ] = UnivariateSpline(
+                    curves[curve][speed]["x"],
+                    curves[curve][speed]["y"],
                 )
+                points_interpolated["UnivariateSpline"][curve][
+                    speed
+                ] = curves_interpolated["UnivariateSpline"][curve][speed](points_x)
 
-            if head_max_error > 0.1:
-                warnings.warn(
-                    f"Head interpolation error in speed {speed} {speed_units}.\n"
+                error = max(
+                    1
+                    - (
+                        points_interpolated["interp1d"][curve][speed]
+                        / points_interpolated["UnivariateSpline"][curve][speed]
+                    )
                 )
-            if eff_curves:
-                if eff_max_error > 0.1:
+                if error > 0.1:
                     warnings.warn(
-                        f"Efficiency interpolation error in speed {speed} {speed_units}.\n"
-                    )
-            if power_curves:
-                if power_max_error > 0.1:
-                    warnings.warn(
-                        f"Power interpolation error in speed {speed} {speed_units}.\n"
+                        f"{curve.capitalize()} interpolation error in speed {speed} {speed_units}.\n"
                     )
 
-            if head_interpolation_method == "UnivariateSpline":
-                head_interpolated = head_spline
-            if eff_curves:
-                if eff_interpolation_method == "UnivariateSpline":
-                    eff_interpolated = eff_spline
-            if power_curves:
-                if power_interpolation_method == "UnivariateSpline":
-                    power_interpolated = power_spline
+            args_list = []
 
-            points_head = head_interpolated(points_x)
+            for flow, param0, param1 in zip(
+                points_x,
+                points_interpolated[interpolation_methods[0]][parameters[0]][speed],
+                points_interpolated[interpolation_methods[1]][parameters[1]][speed],
+            ):
+                arg_dict = {
+                    "suc": suc,
+                    "speed": Q_(float(speed), speed_units),
+                    parameters[0]: Q_(param0, args[f"{parameters[0]}_units"]),
+                    parameters[1]: Q_(param1, args[f"{parameters[1]}_units"]),
+                    "b": b,
+                    "D": D,
+                }
+                if flow_type == "volumetric":
+                    arg_dict["flow_v"] = Q_(flow, flow_units)
+                elif flow_type == "mass":
+                    arg_dict["flow_m"] = Q_(flow, flow_units)
+                args_list.append(arg_dict)
 
-            if eff_curves:
-                points_eff = eff_interpolated(points_x)
-                args_list = [
-                    (
-                        suc,
-                        Q_(float(speed), speed_units),
-                        Q_(flow, flow_units),
-                        Q_(head, head_units),
-                        eff,
-                        b,
-                        D,
-                    )
-                    for flow, head, eff in zip(points_x, points_head, points_eff)
-                ]
-                with multiprocessing.Pool() as pool:
-                    if flow_type == "volumetric":
-                        points += pool.map(create_points_flow_v, args_list)
-                    else:
-                        points += pool.map(create_points_flow_m, args_list)
-
-            if power_curves:
-                points_power = power_interpolated(points_x)
-                args_list = [
-                    (
-                        suc,
-                        Q_(float(speed), speed_units),
-                        Q_(flow, flow_units),
-                        Q_(head, head_units),
-                        Q_(power, power_units),
-                        b,
-                        D,
-                    )
-                    for flow, head, power in zip(points_x, points_head, points_power)
-                ]
-                with multiprocessing.Pool() as pool:
-                    if flow_type == "volumetric":
-                        points += pool.map(create_points_flow_v_power, args_list)
-                    else:
-                        points += pool.map(create_points_flow_m_power, args_list)
+            with multiprocessing.Pool() as pool:
+                points += pool.map(create_points_parallel, args_list)
 
         return cls(points)
 
@@ -752,97 +795,125 @@ class Impeller:
         D=None,
         number_of_points=10,
         flow_units="m**3/s",
+        flow_units_head=None,
+        flow_units_eff=None,
+        flow_units_power=None,
+        flow_units_pressure_ratio=None,
+        flow_units_disch_T=None,
         head_units="J/kg",
+        eff_units="dimensionless",
         power_units="W",
+        pressure_ratio_units="dimensionless",
+        disch_T_units="degK",
         speed_units="RPM",
         head_interpolation_method="interp1d",
         eff_interpolation_method="interp1d",
         power_interpolation_method="interp1d",
+        pressure_ratio_interpolation_method="interp1d",
+        disch_T_interpolation_method="interp1d",
     ):
         """Convert points from csv generated by engauge to csv with 6 points at same flow for use on hysys.
 
-        The csv files should be generated with engauge with the following procedure:
-        First, copy the image of the curve to your clipboard, then inside engauge digitizer:
-            - Edit -> Paste as new
-            - Name each curve with their respective speed value;
-            - On Axis Point -> add 3 reference points
-            - Select the curve (e.g. 10322 would be the curve for 10322 RPM)
-            - Select the points using the segment fill tool;
-            - Select the next curve and points...
-            - Settings -> Export Setup -> Select:
-            - Raws X's and Y's ; One curve on each line
-        Files should be saved with the following convention:
-            - <curve-name>-head.csv
-            - <curve-name>-eff.csv
+         The csv files should be generated with engauge with the following procedure:
+         First, copy the image of the curve to your clipboard, then inside engauge digitizer:
+             - Edit -> Paste as new
+             - Name each curve with their respective speed value;
+             - On Axis Point -> add 3 reference points
+             - Select the curve (e.g. 10322 would be the curve for 10322 RPM)
+             - Select the points using the segment fill tool;
+             - Select the next curve and points...
+             - Settings -> Export Setup -> Select:
+             - Raws X's and Y's ; One curve on each line
+         Files should be saved with the following convention:
+             - <curve-name>-head.csv
+             - <curve-name>-eff.csv
 
-        suc : ccp.State
-            Suction state.
-        curve_path : pathlib.Path
-            Path to the curves.
-        curve_name : str
-            Name for head and efficiency curve.
-            Curves should have names <curve_name>-head.csv and <curve-name>-eff.csv.
-        b : float, pint.Quantity
-            Impeller width (m).
-        D : float, pint.Quantity
-            Impeller diameter (m).
-        number_of_points : int
-            Number of points that will be interpolated.
-        flow_units : str
-            Flow units used when extracting data with engauge.
-        head_units : str
-            Head units used when extracting data with engauge.
-            If the curve head units are in meter you can use: head_units="m*g0".
-        power_units : str
-            Power units used when extracting data with engauge.
-        speed_units : str
-            Speed units used when extracting data with engauge.
-        head_interpolation_method : str, optional
-            Interpolation method from scipy. Can be interp1d or UnivariateSpline.
-            Default is interp1d.
-        eff_interpolation_method : str, optional
-            Interpolation method from scipy. Can be interp1d or UnivariateSpline.
-            Default is interp1d.
-        power_interpolation_method : str, optional
-            Interpolation method from scipy. Can be interp1d or UnivariateSpline.
-            Default is interp1d.
+         suc : ccp.State
+             Suction state.
+         curve_path : pathlib.Path
+             Path to the curves.
+         curve_name : str
+             Name for head and efficiency curve.
+             Curves should have names <curve_name>-head.csv and <curve-name>-eff.csv.
+         b : float, pint.Quantity
+             Impeller width (m).
+         D : float, pint.Quantity
+             Impeller diameter (m).
+         number_of_points : int
+             Number of points that will be interpolated.
+         flow_units : str
+             Flow units used when extracting data with engauge.
+         flow_units_head: str
+             Flow units used when extracting data with engauge for head curves.
+             Only needed when flow units for head curve differs from other curves.
+        flow_units_eff: str
+             Flow units used when extracting data with engauge for efficiency curves.
+             Only needed when flow units for efficiency curve differs from other curves.
+         flow_units_power: str
+             Flow units used when extracting data with engauge for power curves.
+             Only needed when flow units for power curve differs from other curves.
+         flow_units_pressure_ratio: str
+             Flow units used when extracting data with engauge for pressure ratio curves.
+             Only needed when flow units for power curve differs from other curves.
+         flow_units_disch_T: str
+             Flow units used when extracting data with engauge for discharge temperature curves.
+             Only needed when flow units for efficiency curve differs from other curves.
+         head_units : str
+             Head units used when extracting data with engauge.
+             If the curve head units are in meter you can use: head_units="m*g0".
+         eff_units : str
+             Dimensionless.
+         power_units : str
+             Power units used when extracting data with engauge.
+         pressure_ratio_units : str
+             Pressure ratio units used when extracting data with engauge.
+         disch_T_units : str
+             Discharge temperature units used when extracting data with engauge.
+         speed_units : str
+             Speed units used when extracting data with engauge.
+         head_interpolation_method : str, optional
+             Interpolation method from scipy. Can be interp1d or UnivariateSpline.
+             Default is interp1d.
+         eff_interpolation_method : str, optional
+             Interpolation method from scipy. Can be interp1d or UnivariateSpline.
+             Default is interp1d.
+         power_inte![](../../AppData/Local/Temp/logo.png)rpolation_method : str, optional
+             Interpolation method from scipy. Can be interp1d or UnivariateSpline.
+             Default is interp1d.
         """
-        head_path = curve_path / (curve_name + "-head.csv")
-        eff_path = curve_path / (curve_name + "-eff.csv")
-        power_path = curve_path / (curve_name + "-power.csv")
+        curves_path_dict = {}
+        args = locals()
+        for param in ["head", "eff", "power", "pressure_ratio", "disch_T"]:
+            param_path = curve_path / (curve_name + f"-{param}.csv")
+            if param_path.is_file():
+                curves_path_dict[f"{param}_curves"] = read_data_from_engauge_csv(
+                    param_path
+                )
 
-        head_curves = read_data_from_engauge_csv(head_path)
-        if eff_path.is_file():
-            eff_curves = read_data_from_engauge_csv(eff_path)
-            return cls.load_from_dict(
-                suc=suc,
-                b=b,
-                D=D,
-                head_curves=head_curves,
-                eff_curves=eff_curves,
-                number_of_points=number_of_points,
-                flow_units=flow_units,
-                head_units=head_units,
-                speed_units=speed_units,
-                head_interpolation_method=head_interpolation_method,
-                eff_interpolation_method=eff_interpolation_method,
-            )
-        if power_path.is_file():
-            power_curves = read_data_from_engauge_csv(power_path)
-            return cls.load_from_dict(
-                suc=suc,
-                b=b,
-                D=D,
-                head_curves=head_curves,
-                power_curves=power_curves,
-                number_of_points=number_of_points,
-                flow_units=flow_units,
-                head_units=head_units,
-                power_units=power_units,
-                speed_units=speed_units,
-                head_interpolation_method=head_interpolation_method,
-                power_interpolation_method=power_interpolation_method,
-            )
+        return cls.load_from_dict(
+            suc=suc,
+            b=b,
+            D=D,
+            number_of_points=number_of_points,
+            flow_units=flow_units,
+            head_units=head_units,
+            power_units=power_units,
+            flow_units_head=flow_units_head,
+            flow_units_eff=flow_units_eff,
+            flow_units_power=flow_units_power,
+            flow_units_pressure_ratio=flow_units_pressure_ratio,
+            flow_units_disch_T=flow_units_disch_T,
+            eff_units=eff_units,
+            speed_units=speed_units,
+            pressure_ratio_units=pressure_ratio_units,
+            disch_T_units=disch_T_units,
+            head_interpolation_method=head_interpolation_method,
+            eff_interpolation_method=eff_interpolation_method,
+            power_interpolation_method=power_interpolation_method,
+            pressure_ratio_interpolation_method=pressure_ratio_interpolation_method,
+            disch_T_interpolation_method=disch_T_interpolation_method,
+            **curves_path_dict,
+        )
 
     def save(self, file):
         """Save impeller to a toml file.
@@ -993,60 +1064,9 @@ def converter(x):
     return Point.convert_from(point, suc=suc, find=find)
 
 
-def create_points_flow_v(x):
+def create_points_parallel(x):
     """Helper function used to parallelize creation of points."""
-    suc, speed, flow, head, eff, b, D = x
-    return Point(
-        suc=suc,
-        speed=speed,
-        flow_v=flow,
-        head=head,
-        eff=eff,
-        b=b,
-        D=D,
-    )
-
-
-def create_points_flow_m(x):
-    """Helper function used to parallelize creation of points."""
-    suc, speed, flow, head, eff, b, D = x
-    return Point(
-        suc=suc,
-        speed=speed,
-        flow_m=flow,
-        head=head,
-        eff=eff,
-        b=b,
-        D=D,
-    )
-
-
-def create_points_flow_v_power(x):
-    """Helper function used to parallelize creation of points."""
-    suc, speed, flow, head, power, b, D = x
-    return Point(
-        suc=suc,
-        speed=speed,
-        flow_v=flow,
-        head=head,
-        power=power,
-        b=b,
-        D=D,
-    )
-
-
-def create_points_flow_m_power(x):
-    """Helper function used to parallelize creation of points."""
-    suc, speed, flow, head, power, b, D = x
-    return Point(
-        suc=suc,
-        speed=speed,
-        flow_m=flow,
-        head=head,
-        power=power,
-        b=b,
-        D=D,
-    )
+    return Point(**x)
 
 
 def calc_min_head_point(x, speed, imp, min_head):
