@@ -32,6 +32,7 @@ class Point:
         Suction state, polytropic head (J/kg) and gas power (Watt).
     suc, eff, volume_ratio : ccp.State, float, float
         Suction state, polytropic efficiency and volume ratio.
+    suc, pres_ratio, disch_T : ccp.State, float, pint.Quantity or float
     b, D : pint.Quantity, float
         Impeller width and diameter.
 
@@ -109,6 +110,8 @@ class Point:
         phi=None,
         psi=None,
         volume_ratio=None,
+        pressure_ratio=None,
+        disch_T=None,
         b=None,
         D=None,
         polytropic_method=None,
@@ -134,6 +137,8 @@ class Point:
         self.phi = phi
         self.psi = psi
         self.volume_ratio = volume_ratio
+        self.pressure_ratio = pressure_ratio
+        self.disch_T = disch_T
 
         self.b = b
         self.D = D
@@ -142,6 +147,7 @@ class Point:
         self._dummy_state = copy(self.suc)
 
         kwargs_list = []
+        kwargs_dict = {}
 
         for k in [
             "suc",
@@ -156,24 +162,30 @@ class Point:
             "phi",
             "psi",
             "volume_ratio",
+            "pressure_ratio",
+            "disch_T",
         ]:
             if getattr(self, k) is not None:
                 kwargs_list.append(k)
+                kwargs_dict[k] = getattr(self, k)
 
         kwargs_str = "_".join(sorted(kwargs_list))
 
-        getattr(self, "_calc_from_" + kwargs_str)()
+        try:
+            getattr(self, "_calc_from_" + kwargs_str)()
+        except ValueError as e:
+            raise ValueError(f"Could not calculate point with {kwargs_dict}.")
 
         self.reynolds = reynolds(self.suc, self.speed, self.b, self.D)
         self.mach = mach(self.suc, self.speed, self.D)
 
-        self.phi_ratio = 1.0
-        self.psi_ratio = 1.0
-        self.reynolds_ratio = 1.0
+        self.phi_ratio = Q_(1.0, "dimensionless")
+        self.psi_ratio = Q_(1.0, "dimensionless")
+        self.reynolds_ratio = Q_(1.0, "dimensionless")
         # mach in the ptc 10 is compared with Mmt - Mmsp
-        self.mach_diff = 0.0
+        self.mach_diff = Q_(0.0, "dimensionless")
         # ratio between specific volume ratios in original and converted conditions
-        self.volume_ratio_ratio = 1.0
+        self.volume_ratio_ratio = Q_(1.0, "dimensionless")
 
         self._add_point_plot()
 
@@ -352,6 +364,22 @@ class Point:
         self.psi = psi(self.head, self.speed, self.D)
         self.volume_ratio = self.suc.v() / self.disch.v()
 
+    def _calc_from_disch_T_flow_v_pressure_ratio_speed_suc(self):
+        suc = self.suc
+        disch_T = self.disch_T
+        pressure_ratio = self.pressure_ratio
+        disch_p = suc.p() * pressure_ratio
+        self.disch = State.define(p=disch_p, T=disch_T, fluid=suc.fluid)
+        self._calc_from_disch_flow_v_speed_suc()
+
+    def _calc_from_disch_T_flow_m_pressure_ratio_speed_suc(self):
+        suc = self.suc
+        disch_T = self.disch_T
+        pressure_ratio = self.pressure_ratio
+        disch_p = suc.p() * pressure_ratio
+        self.disch = State.define(p=disch_p, T=disch_T, fluid=suc.fluid)
+        self._calc_from_disch_flow_m_speed_suc()
+
     @classmethod
     @check_units
     def convert_from(cls, original_point, suc=None, find="speed", speed=None):
