@@ -21,7 +21,7 @@ def test_state_define():
     assert state.T().units == "kelvin"
     assert state.p().magnitude == 100000
     assert state.T().magnitude == 300
-    assert state.rhomass() == 0.6442542612980722
+    assert_allclose(state.rhomass(), 0.6442542612980722, rtol=1e-7)
 
 
 def test_eos():
@@ -31,7 +31,7 @@ def test_eos():
     assert state.T().units == "kelvin"
     assert state.p().magnitude == 100000
     assert state.T().magnitude == 300
-    assert state.rhomass() == 0.6442542612980722
+    assert_allclose(state.rhomass(), 0.6442542612980722, rtol=1e-7)
 
     ccp.config.EOS = "PR"
     state = State.define(p=100000, T=300, fluid={"Methane": 1 - 1e-15, "Ethane": 1e-15})
@@ -39,7 +39,7 @@ def test_eos():
     assert state.T().units == "kelvin"
     assert state.p().magnitude == 100000
     assert state.T().magnitude == 300
-    assert state.rhomass() == 0.6445687063978816
+    assert_allclose(state.rhomass(), 0.6445687063978816, rtol=1e-7)
 
     ccp.config.EOS = "SRK"
     state = State.define(p=100000, T=300, fluid={"Methane": 1 - 1e-15, "Ethane": 1e-15})
@@ -47,7 +47,7 @@ def test_eos():
     assert state.T().units == "kelvin"
     assert state.p().magnitude == 100000
     assert state.T().magnitude == 300
-    assert state.rhomass() == 0.6442384800595821
+    assert_allclose(state.rhomass(), 0.6442384800595821, rtol=1e-7)
 
     ccp.config.EOS = "HEOS"
     state = State.define(p=100000, T=300, fluid={"Methane": 1 - 1e-15, "Ethane": 1e-15})
@@ -56,6 +56,7 @@ def test_eos():
     assert_allclose(state.p().magnitude, 100000)
     assert state.T().magnitude == 300
     assert state.rhomass() == 0.6442581578304425
+    assert_allclose(state.rhomass(), 0.6442581578304425, rtol=1e-7)
 
     ccp.config.EOS = "REFPROP"
 
@@ -72,7 +73,7 @@ def test_state_define_units():
     assert state.rho().units == "kilogram/meter**3"
     assert state.p().magnitude == 100000
     assert state.T().magnitude == 300
-    assert state.rho().magnitude == 0.6442542612980722
+    assert_allclose(state.rhomass(), 0.6442542612980722, rtol=1e-7)
 
 
 def test_state_define_units_mix():
@@ -157,7 +158,7 @@ def test_h_s_inputs():
     )
     assert_allclose(state.h().magnitude, 755784.43407392, rtol=1e-5)
     assert_allclose(state.s().magnitude, 4805.332018156618, rtol=1e-5)
-    assert_allclose(state.rho().magnitude, 0.9280595769591103)
+    assert_allclose(state.rho().magnitude, 0.9280595769591103, rtol=1e-5)
 
 
 def test_h_p_inputs():
@@ -175,7 +176,7 @@ def test_T_s_inputs():
     )
     assert_allclose(state.h().magnitude, 755784.43407392, rtol=1e-5)
     assert_allclose(state.s().magnitude, 4805.332018156618, rtol=1e-5)
-    assert_allclose(state.rho().magnitude, 0.9280595769591103)
+    assert_allclose(state.rho().magnitude, 0.9280595769591103, rtol=1e-5)
 
 
 def test_equality():
@@ -228,3 +229,70 @@ def test_mix_composition():
 def test_pickle():
     state = State.define(p=100000, T=300, fluid={"Methane": 1 - 1e-15, "Ethane": 1e-15})
     assert pickle.loads(pickle.dumps(state)) == state
+
+
+def test_improved_error_message():
+    with pytest.raises(ValueError) as exc:
+        ccp.State.define(p=100000, T=20, fluid={"methane": 1 - 1e-15, "ethane": 1e-15})
+
+    assert (
+        "Could not define state with {'T': <Quantity(20, 'kelvin')>, 'p': <Quantity(100000, 'pascal')>} and {'METHANE': 0.999999999999999, 'ETHANE': 9.992007221626409e-16}"
+        in str(exc.value)
+    )
+
+
+def test_normalization():
+    suc0 = ccp.State.define(
+        p=Q_("5338000 Pa"),
+        T=Q_("313.15 K"),
+        fluid={
+            "METHANE": 0.48732,
+            "CO2": 0.40163,
+            "ETHANE": 0.05469,
+            "PROPANE": 0.03069,
+            "BUTANE": 0.00970,
+            "PENTANE": 0.00500,
+            "ISOBUTAN": 0.00430,
+            "NITROGEN": 0.00390,
+            "IPENTANE": 0.00190,
+            "HEPTANE": 0.00040,
+            "HEXANE": 0.00020,
+            "NONANE": 0.0,
+            "H2S": 0.00017,
+            "OCTANE": 0.00010,
+            "WATER": 0.00000,
+        },
+    )
+    # same state with different order for fluid names
+    suc1 = ccp.State.define(
+        p=Q_("5338000 Pa"),
+        T=Q_("313.15 K"),
+        fluid={
+            "BUTANE": 0.0097,
+            "CO2": 0.40163,
+            "ETHANE": 0.05469,
+            "H2S": 0.00017,
+            "HEPTANE": 0.0004,
+            "HEXANE": 0.0002,
+            "IPENTANE": 0.0019,
+            "ISOBUTAN": 0.0043,
+            "METHANE": 0.48732,
+            "NITROGEN": 0.0039,
+            "OCTANE": 0.0001,
+            "NONANE": 0.0,
+            "PENTANE": 0.005,
+            "PROPANE": 0.03069,
+            "WATER": 0.0,
+        },
+    )
+
+    assert sum(suc0.fluid.values()) == 1.0
+    assert sum(suc1.fluid.values()) == 1.0
+
+    for k in suc0.fluid.keys():
+        # values won't be equal, since the float sum:  sum(molar_fractions)
+        # is dependent on the list order and will impact in last digits
+        assert suc0.fluid[k] == suc1.fluid[k]
+
+        # no negativa values
+        assert suc0.fluid[k] >= 0.0
